@@ -26,9 +26,9 @@ from littlehttpserver.utils.env import (
     ("/path/to/package-2011.12/build/sphinx/html", "package-2011.12"),
     ("/path/to/package-2012.1.15/build/sphinx/html", "package-2012.1.15"),
     ("/path/to/package_sub-2012.2/build/sphinx/html", "package_sub-2012.2"),
-    ("/path/to/package/docs/", "_path_to_package_docs_"),
-    ("/path/to/package-1.0/docs/", "_path_to_package-1.0_docs_"),
-    ("/path/to/package-sub-1.1/docs/", "_path_to_package-sub-1.1_docs_"),
+    ("/path/to/package/docs/", "package"),
+    ("/path/to/package-1.0/docs/", "package-1.0"),
+    ("/path/to/package-sub-1.1/docs/", "package-sub-1.1"),
 ])
 def test_get_package_name(path, expected):
     assert expected == get_package_name(path)
