@@ -6,26 +6,31 @@ import tempfile
 import os
 from os.path import abspath, basename, isdir, join as pathjoin
 
-_RE_PACKAGE_NAME = re.compile(r"""
-    .*/(?P<pkg_name>\w+.*?[-_]\d+.*?)/(docs?/)?build/(sphinx/)?html/?
+_RE_DOCS_BUILD_DIR = re.compile(r"""
+    (docs?/)?(en/|ja/)?(_?build/)?(sphinx/)?(html/?)?
 """, re.U | re.X)
 
 def get_package_name(path):
-    """ FIXME: should be added more pattern
+    """
     >>> get_package_name("/path/to/package-1.0/build/sphinx/html")
     'package-1.0'
     >>> get_package_name("/path/to/docs/package-1.0/build/html")
     'package-1.0'
     >>> get_package_name("/path/to/package-1.0/docs/build/html")
     'package-1.0'
+    >>> get_package_name("/path/to/package-1.0/docs/_build/html")
+    'package-1.0'
     >>> get_package_name("/path/to/package-1.0/docs/")
-    '_path_to_package-1.0_docs_'
+    'package-1.0'
+    >>> get_package_name("/path/to/package/doc/_build/html")
+    'package'
+    >>> get_package_name("/path/to/package/doc/ja/_build/html")
+    'package'
+    >>> get_package_name("/path/to/package-doc-ja/build/html")  # FIXME
+    'package-doc-ja'
     """
-    match = re.search(_RE_PACKAGE_NAME, path)
-    if match:
-        return match.groupdict().get("pkg_name")
-    else:
-        return path.replace("/", "_")
+    subdir_stripped = re.sub(_RE_DOCS_BUILD_DIR, "", path).rstrip("/")
+    return basename(subdir_stripped)
 
 def make_symlink_to_dir(src, dst):
     abs_path = abspath(src)
